@@ -1,5 +1,6 @@
 import re
 import sys
+import textwrap
 
 import pytest
 
@@ -9,7 +10,17 @@ else:
     from importlib_metadata import version
 
 
-python_3_6_plus = pytest.mark.skipif(sys.version_info < (3, 6), reason="Python 3.6+")
+@pytest.fixture
+def flake8dir(flake8dir):
+    flake8dir.make_setup_cfg(
+        textwrap.dedent(
+            """\
+            [flake8]
+            select = C4
+            """
+        )
+    )
+    yield flake8dir
 
 
 def test_version(flake8dir):
@@ -350,225 +361,6 @@ def test_C406_fail_4(flake8dir):
     ]
 
 
-# C407
-
-
-def test_C407_sum_pass_1(flake8dir):
-    flake8dir.make_example_py(
-        """
-        foo = sum(x + 1 for x in range(10))
-    """
-    )
-    result = flake8dir.run_flake8()
-    assert result.out_lines == []
-
-
-def test_C407_sum_pass_2(flake8dir):
-    flake8dir.make_example_py(
-        """
-        foo = sum({x % 2 for x in range(10)})
-    """
-    )
-    result = flake8dir.run_flake8()
-    assert result.out_lines == []
-
-
-def test_C407_sum_fail_1(flake8dir):
-    flake8dir.make_example_py(
-        """
-        foo = sum([x + 1 for x in range(10)])
-    """
-    )
-    result = flake8dir.run_flake8()
-    assert result.out_lines == [
-        "./example.py:1:7: C407 Unnecessary list comprehension - 'sum' can take "
-        + "a generator."
-    ]
-
-
-def test_C407_filter_pass_1(flake8dir):
-    flake8dir.make_example_py(
-        "filter(lambda x: x % 2 == 0, (x + 1 for x in range(10)))"
-    )
-    result = flake8dir.run_flake8()
-    assert result.out_lines == []
-
-
-def test_C407_filter_pass_2(flake8dir):
-    flake8dir.make_example_py(
-        "filter(lambda x: x % 2 == 0, {x + 1 for x in range(10)})"
-    )
-    result = flake8dir.run_flake8()
-    assert result.out_lines == []
-
-
-def test_C407_filter_fail_1(flake8dir):
-    flake8dir.make_example_py(
-        "filter(lambda x: x % 2 == 0, [x + 1 for x in range(10)])"
-    )
-    result = flake8dir.run_flake8()
-    assert result.out_lines == [
-        "./example.py:1:1: C407 Unnecessary list comprehension - 'filter' can take "
-        + "a generator."
-    ]
-
-
-def test_C407_map_pass_1(flake8dir):
-    flake8dir.make_example_py("map(lambda x: x + 1, (x + 1 for x in range(10)))")
-    result = flake8dir.run_flake8()
-    assert result.out_lines == []
-
-
-def test_C407_map_pass_2(flake8dir):
-    flake8dir.make_example_py("map(lambda x: x + 1, {x + 1 for x in range(10)})")
-    result = flake8dir.run_flake8()
-    assert result.out_lines == []
-
-
-def test_C407_map_fail_1(flake8dir):
-    flake8dir.make_example_py("map(lambda x: x + 1, [x + 1 for x in range(10)])")
-    result = flake8dir.run_flake8()
-    assert result.out_lines == [
-        "./example.py:1:1: C407 Unnecessary list comprehension - 'map' can take "
-        + "a generator."
-    ]
-
-
-def test_C407_map_fail_2(flake8dir):
-    flake8dir.make_example_py(
-        "map(lambda x: x + 1, range(12), [x + 1 for x in range(10)])"
-    )
-    result = flake8dir.run_flake8()
-    assert result.out_lines == [
-        "./example.py:1:1: C407 Unnecessary list comprehension - 'map' can take "
-        + "a generator."
-    ]
-
-
-def test_C407_max_pass_1(flake8dir):
-    flake8dir.make_example_py("max(x + 1 for x in range(10))")
-    result = flake8dir.run_flake8()
-    assert result.out_lines == []
-
-
-def test_C407_max_pass_2(flake8dir):
-    flake8dir.make_example_py("max((x + 1 for x in range(10)), key=lambda x: x * 2)")
-    result = flake8dir.run_flake8()
-    assert result.out_lines == []
-
-
-def test_C407_max_pass_3(flake8dir):
-    flake8dir.make_example_py(
-        "max((x + 1 for x in range(10)), default=1, key=lambda x: x * 2)"
-    )
-    result = flake8dir.run_flake8()
-    assert result.out_lines == []
-
-
-def test_C407_max_pass_4(flake8dir):
-    flake8dir.make_example_py("max({x + 1 for x in range(10)})")
-    result = flake8dir.run_flake8()
-    assert result.out_lines == []
-
-
-def test_C407_max_fail_1(flake8dir):
-    flake8dir.make_example_py("max([x + 1 for x in range(10)])")
-    result = flake8dir.run_flake8()
-    assert result.out_lines == [
-        "./example.py:1:1: C407 Unnecessary list comprehension - 'max' can take "
-        + "a generator."
-    ]
-
-
-def test_C407_max_fail_2(flake8dir):
-    flake8dir.make_example_py("max([x + 1 for x in range(10)], default=1)")
-    result = flake8dir.run_flake8()
-    assert result.out_lines == [
-        "./example.py:1:1: C407 Unnecessary list comprehension - 'max' can take "
-        + "a generator."
-    ]
-
-
-def test_C407_enumerate_pass_1(flake8dir):
-    flake8dir.make_example_py("enumerate(1 for i in range(10))")
-    result = flake8dir.run_flake8()
-    assert result.out_lines == []
-
-
-def test_C407_enumerate_pass_2(flake8dir):
-    flake8dir.make_example_py("enumerate((1 for i in range(10)), 1)")
-    result = flake8dir.run_flake8()
-    assert result.out_lines == []
-
-
-def test_C407_enumerate_pass_3(flake8dir):
-    flake8dir.make_example_py("enumerate((1 for i in range(10)), start=1)")
-    result = flake8dir.run_flake8()
-    assert result.out_lines == []
-
-
-def test_C407_enumerate_fail_1(flake8dir):
-    flake8dir.make_example_py("enumerate([x + 1 for x in range(10)])")
-    result = flake8dir.run_flake8()
-    assert result.out_lines == [
-        "./example.py:1:1: C407 Unnecessary list comprehension - 'enumerate' "
-        + "can take a generator."
-    ]
-
-
-def test_C407_enumerate_fail_2(flake8dir):
-    flake8dir.make_example_py("enumerate([x + 1 for x in range(10)], 1)")
-    result = flake8dir.run_flake8()
-    assert result.out_lines == [
-        "./example.py:1:1: C407 Unnecessary list comprehension - 'enumerate' "
-        + "can take a generator."
-    ]
-
-
-def test_C407_tuple_pass_1(flake8dir):
-    flake8dir.make_example_py(
-        """
-        foo = ()
-    """
-    )
-    result = flake8dir.run_flake8()
-    assert result.out_lines == []
-
-
-def test_C407_tuple_pass_2(flake8dir):
-    flake8dir.make_example_py(
-        """
-        foo = tuple(x + 1 for x in range(10))
-    """
-    )
-    result = flake8dir.run_flake8()
-    assert result.out_lines == []
-
-
-def test_C407_tuple_fail_1(flake8dir):
-    flake8dir.make_example_py(
-        """
-        foo = tuple([x + 1 for x in range(10)])
-    """
-    )
-    result = flake8dir.run_flake8()
-    assert result.out_lines == [
-        "./example.py:1:7: C407 Unnecessary list comprehension - 'tuple' can "
-        + "take a generator."
-    ]
-
-
-def test_it_does_not_crash_on_attribute_functions(flake8dir):
-    flake8dir.make_example_py(
-        """
-        import foo
-        bar = foo.baz(x + 1 for x in range(10))
-    """
-    )
-    result = flake8dir.run_flake8()
-    assert result.out_lines == []
-
-
 # C408
 
 
@@ -828,68 +620,6 @@ def test_C411_fail_1(flake8dir):
     ]
 
 
-# C412
-
-
-def test_C412_pass_1(flake8dir):
-    flake8dir.make_example_py(
-        """
-        [] == [x + 1 for x in range(10)]
-    """
-    )
-    result = flake8dir.run_flake8()
-    assert result.out_lines == []
-
-
-def test_C412_pass_2(flake8dir):
-    flake8dir.make_example_py(
-        """
-        10 in (x + 1 for x in range(10))
-    """
-    )
-    result = flake8dir.run_flake8()
-    assert result.out_lines == []
-
-
-def test_C412_fail_1(flake8dir):
-    flake8dir.make_example_py(
-        """
-        10 in [x + 1 for x in range(10)]
-    """
-    )
-    result = flake8dir.run_flake8()
-    assert result.out_lines == [
-        "./example.py:1:1: C412 Unnecessary list comprehension - 'in' can "
-        + "take a generator."
-    ]
-
-
-def test_C412_fail_2(flake8dir):
-    flake8dir.make_example_py(
-        """
-        10 in {x + 1 for x in range(10)}
-    """
-    )
-    result = flake8dir.run_flake8()
-    assert result.out_lines == [
-        "./example.py:1:1: C412 Unnecessary set comprehension - 'in' can "
-        + "take a generator."
-    ]
-
-
-def test_C412_fail_3(flake8dir):
-    flake8dir.make_example_py(
-        """
-        10 in {x: x + 1 for x in range(10)}
-    """
-    )
-    result = flake8dir.run_flake8()
-    assert result.out_lines == [
-        "./example.py:1:1: C412 Unnecessary dict comprehension - 'in' can "
-        + "take a generator."
-    ]
-
-
 # C413
 
 
@@ -1059,7 +789,6 @@ def test_C416_pass_1(flake8dir):
     assert result.out_lines == []
 
 
-@python_3_6_plus
 def test_C416_pass_2_async_list(flake8dir):
     flake8dir.make_example_py(
         """\
@@ -1071,7 +800,6 @@ def test_C416_pass_2_async_list(flake8dir):
     assert result.out_lines == []
 
 
-@python_3_6_plus
 def test_C416_pass_3_async_set(flake8dir):
     flake8dir.make_example_py(
         """\
